@@ -5,18 +5,17 @@
 # automake to set prefix paths etc. Please keep defaults.py.in
 # in sync between glchess and gnome-sudoku. 
 
-import sys, os, os.path
+import os, os.path
 import errno
 import gettext 
 
 root_dir = os.path.dirname(__file__)
 if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
     # Running in installed mode
-    APP_DATA_DIR     = os.path.join('/usr/local', 'share') 
-    ICON_DIR         = os.path.join(APP_DATA_DIR, 'pixmaps')
-    TEXTURE_DIR      = os.path.join(ICON_DIR, 'glchess')
-    GLADE_DIR        = os.path.join(APP_DATA_DIR, 'glchess')
+    APP_DATA_DIR     = os.path.join('/usr/local', 'share')
     BASE_DIR         = os.path.join(APP_DATA_DIR, 'glchess')
+    TEXTURE_DIR      = os.path.join(BASE_DIR, 'textures')
+    UI_DIR           = BASE_DIR
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
     LOG_DIR          = os.path.join(DATA_DIR, 'logs')
@@ -29,9 +28,8 @@ if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
 else:
     # Running in uninstalled mode
     APP_DATA_DIR     = os.path.join(root_dir, '../../data')
-    ICON_DIR         = os.path.join(root_dir, '../../textures')
     TEXTURE_DIR      = os.path.join(root_dir, '../../textures')
-    GLADE_DIR        = os.path.join(root_dir, '../../glade')
+    UI_DIR           = os.path.join(root_dir, '../../data')
     BASE_DIR         = os.path.join(root_dir, '../../data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
@@ -48,11 +46,7 @@ gettext.bindtextdomain(DOMAIN, LOCALEDIR)
 gettext.textdomain(DOMAIN)
 from gettext import gettext as _
 
-import gtk.glade
-gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
-gtk.glade.textdomain(DOMAIN)
-
-VERSION   = "2.24.3.1"
+VERSION   = "2.28.2"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
