@@ -5,26 +5,26 @@
 # automake to set prefix paths etc. Please keep defaults.py.in
 # in sync between glchess and gnome-sudoku. 
 
-import sys, os, os.path
+import sys, os
 import errno
 import gettext
 
 root_dir = os.path.dirname(os.path.dirname(__file__))
 if not os.path.exists(os.path.join(root_dir, "Makefile.am")):
     # Running in installed mode
-    APP_DATA_DIR = os.path.join('/usr/local', 'share') 
-    IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
+    APP_DATA_DIR = os.path.join('/usr/local', 'share')
+    BASE_DIR = os.path.join(APP_DATA_DIR, 'gnome-sudoku')
+    IMAGE_DIR = os.path.join(BASE_DIR, 'images')
     LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
-    GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
-    BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
-    PUZZLE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku','puzzles')    
+    UI_DIR = BASE_DIR
+    PUZZLE_DIR = os.path.join(BASE_DIR, 'puzzles')
 else:
     # Running in uninstalled mode
     sys.path.insert(0, os.path.abspath(root_dir))
     APP_DATA_DIR = os.path.join(root_dir, '../data') 
     IMAGE_DIR    = os.path.join(root_dir, '../images')
     LOCALEDIR    = os.path.join(APP_DATA_DIR, 'locale')
-    GLADE_DIR    = os.path.join(root_dir, '../glade')
+    UI_DIR    = os.path.join(root_dir, '../data')
     BASE_DIR     = os.path.join(root_dir, '../data')
     PUZZLE_DIR   = BASE_DIR
 
@@ -32,11 +32,8 @@ DOMAIN = 'gnome-games'
 gettext.bindtextdomain(DOMAIN, LOCALEDIR)
 gettext.textdomain(DOMAIN)
 from gettext import gettext as _
-import gtk.glade
-gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
-gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.24.3.1"
+VERSION = "2.28.2"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2008, Thomas M. Hinkle'
@@ -44,7 +41,7 @@ DESCRIPTION = _('GNOME Sudoku is a simple sudoku generator and player. Sudoku is
 AUTHORS = ["Thomas M. Hinkle"]
 WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
 WEBSITE_LABEL = _('GNOME Games web site')
-AUTO_SAVE= True
+AUTO_SAVE = True
 MIN_NEW_PUZZLES = 90
 
 # The GPL license string will be translated, and the game name inserted.
